@@ -294,6 +294,7 @@ id.ngml <- function(x, stage3 = FALSE){
   if(stage3 == TRUE){
     #y <- t(x$y)
     yl <- t(y_lag_cr(t(y), p)$lags)
+    y_return <- y
 
     y <- y[,-c(1:p)]
 
@@ -347,6 +348,7 @@ id.ngml <- function(x, stage3 = FALSE){
     maxL2 <- nlm(p = A, f = loglik2, hessian = TRUE)
 
     A_hat <- matrix(maxL2$estimate, nrow = k)
+    y <- y_return
   }else{
     if(inherits(x, "var.boot")){
       A_hat <- coef_x
@@ -393,40 +395,7 @@ id.ngml <- function(x, stage3 = FALSE){
   }
 
 
-  # ordering the columns with respect to the largest absolute values in each column
-  B_hat_ord <- matrix(0, k, k)
-  control <- rep(0, k)
-  for(i in 1:ncol(B_mle)){
-    for(j in 1:ncol(B_mle)){
-      if(which.max(abs(B_mle[, j])) == i){
-        if(control[i] == 0){
-          control[i] <- j
-          B_hat_ord[, i] <- B_mle[, j]
-        }else{
-          if(max(B_mle[, j]) > max(B_mle[, control[i]])){
-            control[i] <- j
-            B_hat_ord[, i] <- B_mle[, j]
-          }
-        }
-      }
-    }
-  }
-
-  # checking if any column in the orderd matrix is empty and replace it with the unused column in the estimated matrix
-  if(any(control == 0)){
-    hc <- sapply(1:k, function(x){any(x == control)})
-    B_hat_ord[, which(control == 0)] <- B_mle[, which(hc == FALSE)]
-    control[which(control == 0)] <- which(hc == FALSE)
-  }
-
-  # checking for negative values on the main diagonal
-  for(i in 1:ncol(B_hat_ord)){
-    if(B_hat_ord[i,i] < 0){
-      B_hat_ord[, i] <- B_hat_ord[, i]*(-1)
-    }
-  }
-
-  result <- list(B = B_hat_ord,       # estimated B matrix (unique decomposition of the covariance matrix)
+  result <- list(B = B_mle,       # estimated B matrix (unique decomposition of the covariance matrix)
                  B_SE = B.SE.2,          # standard errors
                  sigma = sigma_est,      # estimated scale of the standardized B
                  sigma_SE = sigma_SE,    # standard errors of the scale
