@@ -2,15 +2,15 @@ identifyVolatility = function(x, SB, Tob = Tob, u_t = u_t, k = k, y = y, restric
                                Sigma_hat1 = Sigma_hat1, Sigma_hat2 = Sigma_hat2, p = p, TB = TB, SBcharacter,
                                max.iter, crit = crit){
 
-  MW <- -1
-  while(MW < 0.5){
-    B <- suppressMessages(expm::sqrtm((1/Tob)* crossprod(u_t))) + matrix(runif(k*k), nrow = k, byrow = T)
-    MW <- det(tcrossprod(B))
-  }
-  B <- c(B)
+
   if(!is.null(restriction_matrix)){
+    B <- t(chol((1/Tob)* crossprod(u_t)))
+    naElements <- is.na(restriction_matrix)
+    B <- B[naElements]
     restrictions <- length(restriction_matrix[!is.na(restriction_matrix)])
-    B <- B[1:(length(B)-restrictions)]
+  }else{
+    B <- t(chol((1/Tob)* crossprod(u_t)))
+    B <- c(B)
   }
   Lambda <- rep(1, k)
   S <- c(B, Lambda)
@@ -18,19 +18,11 @@ identifyVolatility = function(x, SB, Tob = Tob, u_t = u_t, k = k, y = y, restric
   # optimize the likelihood function
   MLE <- nlm(f = LH, p = S, k = k, TB = TB, Sigma_hat1 = Sigma_hat1,
              Sigma_hat2 = Sigma_hat2, Tob = Tob, hessian = T, restriction_matrix = restriction_matrix,
-             restrictions = restrictions)
+             restrictions = restrictions, iterlim = 150)
 
   if(!is.null(restriction_matrix)){
     naElements <- is.na(restriction_matrix)
-    Lam <- diag(MLE$estimate[(sum(naElements) + 1):length(MLE$estimate)])
-  }else{
-    Lam <- diag(MLE$estimate[(k*k+1):(k*k+k)])
-  }
-
-
-  if(!is.null(restriction_matrix)){
-    naElements <- is.na(restriction_matrix)
-    B_hat = restriction_matrix
+    B_hat <- restriction_matrix
     B_hat[naElements] <- MLE$estimate[1:sum(naElements)]
     Lambda_hat <- diag(MLE$estimate[(sum(naElements) + 1):length(MLE$estimate)])
   }else{
@@ -41,32 +33,30 @@ identifyVolatility = function(x, SB, Tob = Tob, u_t = u_t, k = k, y = y, restric
   ll <- MLE$minimum
 
   # estimating again with GLS to obatin a more precise estimation
-  #y <- t(x$y)
-
-  y_lag_cr <- function(y, lag_length){
-    # create matrix that stores the lags
-    y_lag <- matrix(NA, dim(y)[1],dim(y)[2]*lag_length)
-    for (i in 1:lag_length) {
-      y_lag[(1+i):dim(y)[1],((i*NCOL(y)-NCOL(y))+1):(i*NCOL(y))] <- y[1:(dim(y)[1]-i),(1:NCOL(y))]
+    y_lag_cr <- function(y, lag_length){
+      # create matrix that stores the lags
+      y_lag <- matrix(NA, dim(y)[1],dim(y)[2]*lag_length)
+      for (i in 1:lag_length) {
+        y_lag[(1+i):dim(y)[1],((i*NCOL(y)-NCOL(y))+1):(i*NCOL(y))] <- y[1:(dim(y)[1]-i),(1:NCOL(y))]
+      }
+      # drop first observation
+      y_lag <- as.matrix(y_lag[-(1:lag_length),])
+      out <- list(lags = y_lag)
     }
-    # drop first observation
-    y_lag <- as.matrix(y_lag[-(1:lag_length),])
-    out <- list(lags = y_lag)
-  }
 
-  yl <- t(y_lag_cr(t(y), p)$lags)
-  yret <- y
-  y <- y[,-c(1:p)]
+    yl <- t(y_lag_cr(t(y), p)$lags)
+    yret <- y
+    y <- y[,-c(1:p)]
 
-  if(x$type == 'const'){
-    Z_t <- rbind(rep(1, ncol(yl)), yl)
-  }else if(x$type == 'trend'){
-    Z_t <- rbind(seq(1, ncol(yl)), yl)
-  }else if(x$type == 'both'){
-    Z_t <- rbind(rep(1, ncol(yl)), seq(1, ncol(yl)), yl)
-  }else{
-    Z_t <- yl
-  }
+    if(x$type == 'const'){
+      Z_t <- rbind(rep(1, ncol(yl)), yl)
+    }else if(x$type == 'trend'){
+      Z_t <- rbind(seq(1, ncol(yl)), yl)
+    }else if(x$type == 'both'){
+      Z_t <- rbind(rep(1, ncol(yl)), seq(1, ncol(yl)), yl)
+    }else{
+      Z_t <- yl
+    }
 
   gls1 <- function(Z, Sig){
     G <- kronecker(tcrossprod(Z), Sig)
@@ -81,6 +71,8 @@ identifyVolatility = function(x, SB, Tob = Tob, u_t = u_t, k = k, y = y, restric
   Lambda_hat <- list(Lambda_hat)
   B_hat <- list(B_hat)
   ll <- list(ll)
+  MLEgls_loop <- list(MLE)
+  GLSE <- list(NULL)
 
   counter <- 1
   Exit <- 1
@@ -130,29 +122,22 @@ identifyVolatility = function(x, SB, Tob = Tob, u_t = u_t, k = k, y = y, restric
     Sigma_hat2gls <- (crossprod(resid2gls)) / (Tob-TB+1)
 
     # Determine starting values for B and Lambda
-    MW <- -1
-    while(MW < 0.5){
-      B <- suppressMessages(expm::sqrtm((1/Tob)* crossprod(u_tgls))) + matrix(runif(k*k), nrow = k, byrow = T)
-      MW <- det(tcrossprod(B))
-    }
-    B <- c(B)
     if(!is.null(restriction_matrix)){
+      B <- t(chol((1/Tob)* crossprod(u_t)))
+      naElements <- is.na(restriction_matrix)
+      B <- B[naElements]
       restrictions <- length(restriction_matrix[!is.na(restriction_matrix)])
-      B <- B[1:(length(B)-restrictions)]
+    }else{
+      B <- t(chol((1/Tob)* crossprod(u_t)))
+      B <- c(B)
     }
     Lambda <- rep(1, k)
     S <- c(B, Lambda)
 
     #optimize the likelihood function
     MLEgls <- nlm(f = LH, p = S, k = k, TB = TB, Sigma_hat1 = Sigma_hat1gls,
-                  Sigma_hat2 = Sigma_hat2gls, Tob = Tob, hessian = T, restriction_matrix = restriction_matrix, restrictions = restrictions)
-
-    if(!is.null(restriction_matrix)){
-      naElements <- is.na(restriction_matrix)
-      Lam <- diag(MLE$estimate[(sum(naElements) + 1):length(MLE$estimate)])
-    }else{
-      Lam <- diag(MLE$estimate[(k*k+1):(k*k+k)])
-    }
+                  Sigma_hat2 = Sigma_hat2gls, Tob = Tob, hessian = T, restriction_matrix = restriction_matrix,
+                  restrictions = restrictions, iterlim = 150)
 
     if(!is.null(restriction_matrix)){
       naElements <- is.na(restriction_matrix)
@@ -169,15 +154,10 @@ identifyVolatility = function(x, SB, Tob = Tob, u_t = u_t, k = k, y = y, restric
     B_hat <- c(B_hat, list(B_hatg))
     Lambda_hat <- c(Lambda_hat, list(Lambda_hatg))
     ll <- c(ll, list(ll_g))
-
-    if(counter == 1){
-      GLSE <- list(GLS_hat)
-    }else{
-      GLSE <- c(GLSE, list(GLS_hat))
-    }
-
+    GLSE <- c(GLSE, list(GLS_hat))
+    MLEgls_loop <- c(MLEgls_loop, list(MLEgls))
     counter <- counter + 1
-    #Exit <- sum(diag(Lambda_hat[[counter]])) - sum(diag(Lambda_hat[[counter - 1]]))
+
     Exit <- ll[[counter]] - ll[[counter-1]]
   }
 
@@ -187,8 +167,11 @@ identifyVolatility = function(x, SB, Tob = Tob, u_t = u_t, k = k, y = y, restric
   cc <- which.min(ll)
   B_hat <- B_hat[[cc]]
   Lambda_hat <- Lambda_hat[[cc]]
-  GLSE <- GLSE[[cc-1]]
-  GLSE <- matrix(GLSE, nrow = k)
+  GLSE <- GLSE[[cc]]
+  if(!is.null(GLSE)){
+    GLSE <- matrix(GLSE, nrow = k)
+  }
+  MLEgls <- MLEgls_loop[[cc]]
 
   # obtaining standard errors from inverse fisher information matrix
   HESS <- solve(MLEgls$hessian)
@@ -231,7 +214,7 @@ identifyVolatility = function(x, SB, Tob = Tob, u_t = u_t, k = k, y = y, restric
     SBcharacter = SBcharacter,             # Structural Break in input character format
     restrictions = restrictions, # number of restrictions
     y = t(yret),                # Data
-    p = p,                # number of lags
+    p = unname(p),                # number of lags
     K = k                 # number of time series
   )
   return(result)
